@@ -8,8 +8,14 @@
 #
 package XML::LibXML::Error;
 
-use Encode ();
 use strict;
+use warnings;
+
+# To avoid a "Deep recursion on subroutine as_string" warning
+no warnings 'recursion';
+
+use Encode ();
+
 use vars qw(@error_domains $VERSION $WARNINGS);
 use Carp;
 use overload 
@@ -23,7 +29,7 @@ use overload
   fallback => 1;
 
 $WARNINGS = 0; # 0: supress, 1: report via warn, 2: report via die
-$VERSION = "1.73"; # VERSION TEMPLATE: DO NOT CHANGE
+$VERSION = "1.88"; # VERSION TEMPLATE: DO NOT CHANGE
 
 use constant XML_ERR_NONE            => 0;
 use constant XML_ERR_WARNING         => 1; # A simple warning
